@@ -27,8 +27,29 @@ bool DecodeArgs(int argc, char ** argv)
       }
       switch (c) {
       case 'd':       /* selects Debug output */
+	if (*p>'9' && *p!='-') {
+	  if (strncmp(p,"vinum",8)==0) { 
+	    dvipagenum = (p[9] != '0');
+	    if (dvipagenum)
+	      Message(PARSE_STDIN,"DVI page number output on\n",p);
+	    else 
+	      Message(PARSE_STDIN,"DVI page number output off\n");
+	    break;
+	  } else if (strncmp(p,"epth",4)==0) { /* Depth reporting */ 
+	  if (p[8] != '0')
+	    flags |= REPORT_DEPTH;
+	  else
+	    flags &= !REPORT_DEPTH;
+	  break;
+	  if (flags & REPORT_DEPTH )
+	    Message(PARSE_STDIN,"Depth reporting on\n",p);
+	  else 
+	    Message(PARSE_STDIN,"Depth reporting off\n");
+	  break;
+	}
+	  goto DEFAULT;
+	} else { 
 #ifdef DEBUG
-	{ 
 	  int debug = 0;
 	  
 	  if (*p == 0 && argv[i+1])
@@ -37,16 +58,16 @@ bool DecodeArgs(int argc, char ** argv)
 	  flags |= (debug>0) ? debug * DEBUG_DEFAULT : DEBUG_DVI;
 	  if (debug > 0 && p == argv[i+1])
 	    i++;
+	  Message(PARSE_STDIN,"Debug output enabled\n");
 #ifdef HAVE_LIBKPATHSEA
 	  kpathsea_debug = ( debug * DEBUG_DEFAULT) / LASTDEBUG;
 #endif
-	  Message(PARSE_STDIN,"Debug output enabled\n");
-	}
 #else
-	Warning("This instance of %s was compiled without the debug (-d) option",
-		programname);
+	  Warning("This instance of %s was compiled without the debug (-d) option",
+		  programname);
 #endif
-        break;
+	  break;
+	}
       case 'o':       /* Output file is specified */
 	if (*p == 0 && argv[i+1])
 	  p = argv[++i] ;
@@ -78,6 +99,17 @@ bool DecodeArgs(int argc, char ** argv)
       case 'h':
 	if (strcmp(p,"elp") == 0 ) {
 	  break;
+	} else if (strncmp(p,"eight",5) == 0 ) { /* Height reporting */ 
+	  if (p[8] != '0')
+	    flags |= REPORT_HEIGHT;
+	  else
+	    flags &= !REPORT_HEIGHT;
+	  break;
+	  if (flags & REPORT_HEIGHT )
+	    Message(PARSE_STDIN,"Height reporting on\n",p);
+	  else 
+	    Message(PARSE_STDIN,"Height reporting off\n");
+	  break;
 	}
 	goto DEFAULT;
 #endif /* MAKETEXPK */
@@ -167,18 +199,7 @@ bool DecodeArgs(int argc, char ** argv)
 	  borderwidth = atoi(p);
 	  Message(PARSE_STDIN,"Transp. border: %d dots\n",borderwidth);
 	  break;
-	} else if (strncmp(p,"aseline",7)==0) { /* Baseline reporting */ 
-	  if (p[8] != '0')
-	    flags |= REPORT_BASELINE;
-	  else
-	    flags &= !REPORT_BASELINE;
-	  break;
-	  if (flags & REPORT_BASELINE )
-	    Message(PARSE_STDIN,"Baseline reporting on\n",p);
-	  else 
-	    Message(PARSE_STDIN,"Baseline reporting off\n");
-	  break;
-	}
+	} 
 	goto DEFAULT;
       case 'f':
 	if ( *p == 'g' ) { /* -fg foreground color */
@@ -320,8 +341,9 @@ named COPYING and dvipng.c.");
     }
   }
 
-  Message(BE_NONQUIET,"This is %s Copyright 2002-2003 Jan-ke Larsson\n",
-	  PACKAGE_STRING);
+  if (programname)
+    Message(BE_NONQUIET,"This is %s Copyright 2002-2003 Jan-ke Larsson\n",
+	    PACKAGE_STRING);
 
   if (dviname != NULL) {
     if (dvi != NULL && dvi->filep != NULL) 
@@ -380,7 +402,7 @@ named COPYING and dvipng.c.");
     }
   }
   if ((flags & PARSE_STDIN) == 0 && (! ppused)) 
-    ParsePages("--");
+    ParsePages("-");
   return((flags & PARSE_STDIN) != 0);
 }
 /*
@@ -455,9 +477,14 @@ void Fatal (char *fmt, ...)
   fprintf(stderr, "\n");
   fprintf(stderr, "%s: Fatal error, ", programname);
   vfprintf(stderr, fmt, args);
-
+  
   fprintf(stderr, "\n\n");
   va_end(args);
+
+  ClearFonts();
+#ifdef HAVE_FT2
+  (void) FT_Done_FreeType(libfreetype); /* at this point, ignore error */
+#endif  
   exit(EXIT_FAILURE);
 }
 
