@@ -3,29 +3,34 @@
 #include <sys/mman.h>
 #include <sys/stat.h>
 
-void ReadTFM(struct font_entry * tfontp, char* tfmname)
+bool ReadTFM(struct font_entry * tfontp, char* tfmname)
 {
   struct stat stat;
   struct ft_char *tcharptr;  
   int filedes;
   unsigned char* filemmap,*position; 
   int lh,bc,ec,nw, c;
-  int32_t* width;
+  dviunits* width;
 
   DEBUG_PRINT(((DEBUG_DVI|DEBUG_FT|DEBUG_TFM),
 	       "\n  OPEN METRICS:\t'%s'", tfmname));
-  if ((filedes = open(tfmname,O_RDONLY)) == -1) 
+  if ((filedes = open(tfmname,O_RDONLY)) == -1) {
     Warning("metric file %s could not be opened", tfmname);
+    return(false);
+  }
   fstat(filedes,&stat);
   filemmap = mmap(NULL,stat.st_size, PROT_READ, MAP_SHARED,filedes,0);
-  if (filemmap == (unsigned char *)-1) 
-    Fatal("cannot mmap metric file %s",tfmname);
+  if (filemmap == (unsigned char *)-1) {
+    Warning("cannot mmap metric file %s",tfmname);
+    close(filedes);
+    return(false);
+  }
   lh = UNumRead(filemmap+2,2);
   bc = UNumRead(filemmap+4,2);
   ec = UNumRead(filemmap+6,2);
   nw = UNumRead(filemmap+8,2);
   DEBUG_PRINT((DEBUG_TFM," %d %d %d %d",lh,bc,ec,nw));
-  width=xmalloc(nw*sizeof(int32_t));  
+  width=alloca(nw*sizeof(dviunits));  
   c=0;
   position=filemmap+24+(lh+ec-bc+1)*4;
   while( c < nw ) {
@@ -33,7 +38,6 @@ void ReadTFM(struct font_entry * tfontp, char* tfmname)
     c++;
     position += 4; 
   }
-
   
   /* Read char widths */
   c=bc;
@@ -45,7 +49,7 @@ void ReadTFM(struct font_entry * tfontp, char* tfmname)
     tcharptr->data=NULL;
     tcharptr->tfmw=width[*position];
     DEBUG_PRINT((DEBUG_TFM,"%d [%d] %d",c,*position,tcharptr->tfmw));
-    tcharptr->tfmw = (int32_t) 
+    tcharptr->tfmw = (dviunits) 
       ((int64_t) tcharptr->tfmw * tfontp->s / (1 << 20));
     DEBUG_PRINT((DEBUG_TFM," (%d)",tcharptr->tfmw));
     if (c > NFNTCHARS) /* Only positive for now */
@@ -55,6 +59,7 @@ void ReadTFM(struct font_entry * tfontp, char* tfmname)
     position += 4;
   }
   free(width);
+  return(true);
 }
   
 
